Method for rendering a page with a given layout and components
.render_page(
title,
components,
layout = c("default", "storyboard", "focal_left", "2x2_grid"),
menu = NULL,
sidebar = NULL
)A markdown string with the final page.
The page title.
A list of page components.
The pages overall layout.
The menu under which the page will be filed.
Character string with sidebar content.